import { EventEmitter } from 'events';
import { Buffer } from 'buffer';
export { Buffer };
declare enum WebSocketState {
    CONNECTING = 0,
    OPEN = 1,
    CLOSING = 2,
    CLOSED = 3
}
export declare class WebSocket extends EventEmitter {
    private readonly options;
    private socket?;
    private pre_ready_sent_messages;
    private timer?;
    /**
     * Constructs a new instances of the class
     * @param options
     */
    constructor(options: WebSocket.Options);
    /**
     * Returns the underlying WebSocket's binary type
     */
    get binaryType(): 'arraybuffer' | 'nodebuffer' | 'fragments';
    /**
     * Sets the underlying WebSocket's binary type
     *
     * @param value
     */
    set binaryType(value: 'arraybuffer' | 'nodebuffer' | 'fragments');
    /**
     * Returns the amount of data buffered by the underlying WebSocket
     */
    get bufferedAmount(): number;
    /**
     * Returns any extensions currently enabled in the underlying WebSocket
     */
    get extensions(): string;
    /**
     * Returns the underlying WebSocket protocol
     */
    get protocol(): string;
    /**
     * Returns the underlying WebSocket's ready state
     */
    get readyState(): WebSocket.State;
    /**
     * Returns the underlying WebSocket's remote URL
     */
    get url(): string;
    /**
     * Emitted when the underlying WebSocket is closed
     *
     * @param event
     * @param listener
     */
    on(event: 'close', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket encounters an error
     *
     * @param event
     * @param listener
     */
    on(event: 'error', listener: (error: Error) => void): this;
    /**
     * Emitted when the underlying WebSocket receives a message
     *
     * @param event
     * @param listener
     */
    on(event: 'message', listener: (message: Buffer) => void): this;
    /**
     * Emitted when the underlying WebSocket is opened
     *
     * @param event
     * @param listener
     */
    on(event: 'open', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket is ready
     *
     * @param event
     * @param listener
     */
    on(event: 'ready', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket is closed
     *
     * @param event
     * @param listener
     */
    once(event: 'close', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket encounters an error
     *
     * @param event
     * @param listener
     */
    once(event: 'error', listener: (error: Error) => void): this;
    /**
     * Emitted when the underlying WebSocket receives a message
     *
     * @param event
     * @param listener
     */
    once(event: 'message', listener: (message: Buffer) => void): this;
    /**
     * Emitted when the underlying WebSocket is opened
     *
     * @param event
     * @param listener
     */
    once(event: 'open', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket is ready
     *
     * @param event
     * @param listener
     */
    once(event: 'ready', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket is closed
     *
     * @param event
     * @param listener
     */
    off(event: 'close', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket encounters an error
     *
     * @param event
     * @param listener
     */
    off(event: 'error', listener: (error: Error) => void): this;
    /**
     * Emitted when the underlying WebSocket receives a message
     *
     * @param event
     * @param listener
     */
    off(event: 'message', listener: (message: Buffer) => void): this;
    /**
     * Emitted when the underlying WebSocket is opened
     *
     * @param event
     * @param listener
     */
    off(event: 'open', listener: () => void): this;
    /**
     * Emitted when the underlying WebSocket is ready
     *
     * @param event
     * @param listener
     */
    off(event: 'ready', listener: () => void): this;
    /**
     * Attempts to connect the underlying WebSocket to the remote URL
     *
     * This method also allows us to re-use the class instance, so we do not have
     * to recreate it if we need to 'reconnect' the WebSocket later
     */
    open(): void;
    /**
     * Alias for `open()`
     */
    connect(): void;
    /**
     * Closes the underlying WebSocket
     *
     * @param code
     * @param reason
     */
    close(code?: number, reason?: string): void;
    /**
     * Sends the specified data via the underlying WebSocket
     *
     * @param data
     */
    send(data: string | ArrayBufferLike | ArrayBufferView | Buffer): void;
}
export declare namespace WebSocket {
    type State = WebSocketState;
    type Options = {
        url: string;
        protocols?: string | string[];
        binaryType?: 'arraybuffer' | 'nodebuffer' | 'fragments';
        autoReconnect?: boolean;
    };
}
export default WebSocket;
